==> haskell-test-framework-quickcheck2-0.3.0.5-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-quickcheck2
version: 0.3.0.5
id: test-framework-quickcheck2-0.3.0.5-FXuHVesmf797eTBioOzOT
key: test-framework-quickcheck2-0.3.0.5-FXuHVesmf797eTBioOzOT
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: http://haskell.github.io/test-framework/
synopsis: QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.
category: Testing
abi: ece26f574ef704fa20285ccfbbec8507
exposed: True
exposed-modules:
    Test.Framework.Providers.QuickCheck2
import-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-quickcheck2-0.3.0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-quickcheck2-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/test-framework-quickcheck2-0.3.0.5
hs-libraries: HStest-framework-quickcheck2-0.3.0.5-FXuHVesmf797eTBioOzOT
depends:
    QuickCheck-2.13.2-2FrYL0Zx0JL1157x99MUYA base-4.12.0.0
    extensible-exceptions-0.1.1.4-KI0dG6kQM84KnSzvR2Yb0
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    test-framework-0.8.2.0-2dhLXXIyuWjLumyCVFTYFd
haddock-interfaces: /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock
haddock-html: /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-quickcheck2-0.3.0.5-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-quickcheck2
version: 0.3.0.5
id: test-framework-quickcheck2-0.3.0.5-Aj8T1U3Y23nCRL1C6OQRaX
key: test-framework-quickcheck2-0.3.0.5-Aj8T1U3Y23nCRL1C6OQRaX
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: http://haskell.github.io/test-framework/
synopsis: QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.
category: Testing
abi: b95d3d053e0a79c20d927c7c88ce1394
exposed: True
exposed-modules:
    Test.Framework.Providers.QuickCheck2
import-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-quickcheck2-0.3.0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-quickcheck2-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/test-framework-quickcheck2-0.3.0.5
hs-libraries: HStest-framework-quickcheck2-0.3.0.5-Aj8T1U3Y23nCRL1C6OQRaX
depends:
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW base-4.12.0.0
    extensible-exceptions-0.1.1.4-KI0dG6kQM84KnSzvR2Yb0
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    test-framework-0.8.2.0-2dhLXXIyuWjLumyCVFTYFd
haddock-interfaces: /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock
haddock-html: /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
